@@ -81,6 +81,6 @@ class BackslashPostProcessor(Postprocessor):
 
 	def run(self, text):
 		text = text.replace('<br />\n', '</li>\n<li>')
-		text = re.sub(r'<a href="(.*)"><img', r'<a href="\1" class="none"><img', text)
+		text = re.sub(r'<a href="(.*)"><img', r'<a href="\1" class="img"><img', text)
 		return text
 
